<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <source>Jump to today</source>
        <translation>Gehe zu: Heute</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="29"/>
        <source>Jump to</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="30"/>
        <source>New event</source>
        <translation>Neues Ereignis</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="20"/>
        <source>Agenda</source>
        <translation>Planung</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="38"/>
        <source>In advance</source>
        <translation>Im Voraus</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="48"/>
        <source>Arbitrary</source>
        <translation>Beliebig</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="66"/>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="86"/>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="106"/>
        <source>Seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="20"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="152"/>
        <source>None</source>
        <translation>Keiner</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="164"/>
        <source>Exact</source>
        <translation>Genau</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="166"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n Stunde vorher</numerusform>
            <numerusform>%n Stunden vorher</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="167"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n Minute vorher</numerusform>
            <numerusform>%n Minuten vorher</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="168"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n Sekunde vorher</numerusform>
            <numerusform>%n Sekunden vorher</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="170"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 vorher</translation>
    </message>
</context>
<context>
    <name>BirthdayEditDialog</name>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="6"/>
        <source>Edit event</source>
        <translation>Ereignis bearbeiten</translation>
    </message>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="12"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>From beginning</source>
        <translation>Vom Beginn</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="38"/>
        <source>From end</source>
        <translation>Vom Ende</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="49"/>
        <source>By day of month</source>
        <translation>Am Tag des Monats</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="51"/>
        <source>By week of year</source>
        <translation>In der Woche des Jahres</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="53"/>
        <source>By day of year</source>
        <translation>Am Tag des Jahres</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="20"/>
        <source>By month</source>
        <translation>Im Monat</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="21"/>
        <source>By day of week</source>
        <translation>Am Tag der Woche</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="55"/>
        <source>From beginning</source>
        <translation>Vom Beginn</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="56"/>
        <source>From end</source>
        <translation>Vom Ende</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="52"/>
        <source>Edit calendar</source>
        <translation>Kalender bearbeiten</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="27"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="37"/>
        <source>Birthday</source>
        <translation>Geburtstag</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="53"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="63"/>
        <source>Visible</source>
        <translation>Sichtbar</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="42"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="43"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="90"/>
        <source>New calendar</source>
        <translation>Neuer Kalender</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="94"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="141"/>
        <location filename="../settings/CalendarEditDialog.cpp" line="166"/>
        <source>Error occurred</source>
        <translation>Ein Fehler ist aufgetreten</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="175"/>
        <source>Save file</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="193"/>
        <source>This calendar cannot be deleted. Delete all calendar content instead?</source>
        <translation>Der Kalender kann nicht entfernt werden. Soll stattdessen der gesamte Inhalt gelöscht werden?</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="201"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Diesen Kalender inkl. seiner Termine, Aufgaben und Notizen löschen?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Kalender bearbeiten</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="27"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n sichtbar</numerusform>
            <numerusform>%n sichtbar</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChangeManager</name>
    <message>
        <location filename="../ChangeManager.cpp" line="239"/>
        <source>Delete event?</source>
        <translation>Ereignis löschen?</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="242"/>
        <source>Delete task?</source>
        <translation>Aufgabe löschen?</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="245"/>
        <source>Delete note?</source>
        <translation>Notiz löschen?</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="248"/>
        <source>Delete component?</source>
        <translation>Eintrag löschen?</translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Ganz-
tägig</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="71"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Clone</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="183"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="184"/>
        <source>Clone</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="185"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>DateFormatDialog</name>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="6"/>
        <source>Date formats</source>
        <translation>Datumsformate</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="20"/>
        <source>Full</source>
        <translation>Lang</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="37"/>
        <source>Partial</source>
        <translation>Kurz</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="72"/>
        <source>Day</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="89"/>
        <source>Month</source>
        <translation>Monat</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="106"/>
        <source>Year</source>
        <translation>Jahr</translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.cpp" line="24"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="16"/>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="161"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Woche %1 (%2-%3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="19"/>
        <source>Select date</source>
        <translation>Datum auswählen</translation>
    </message>
</context>
<context>
    <name>DateTimePickDialog</name>
    <message>
        <location filename="../DateTimePickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Tag als Zahl eingeben</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Vorheriger Tag</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Nächster Tag</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Gehe zu: Heute</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Gehe zu</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n Ereignis</numerusform>
            <numerusform>%n Ereignisse</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n Aufgabe</numerusform>
            <numerusform>%n Aufgaben</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n Notiz</numerusform>
            <numerusform>%n Notizen</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Ort</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Ganztägig</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Von</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Bis</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Time zone</source>
        <translation>Zeitzone</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="125"/>
        <source>Repeat</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="142"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="149"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="30"/>
        <source>Edit event</source>
        <translation>Ereignis bearbeiten</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="33"/>
        <source>New event</source>
        <translation>Neues Ereignis</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Ereignis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>Bis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Previous event</source>
        <translation>Vorheriges Ereignis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Next event</source>
        <translation>Nächstes Ereignis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Edit event</source>
        <translation>Ereignis bearbeiten</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="197"/>
        <source>Delete event</source>
        <translation>Ereignis löschen</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="202"/>
        <source>Clone event</source>
        <translation>Ereignis duplizieren</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="207"/>
        <source>Automatic links</source>
        <translation>Automatische Verknüpfungen</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="149"/>
        <source>From</source>
        <translation>Von</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="149"/>
        <source>On</source>
        <translation>Am</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="219"/>
        <location filename="../EventWindow.cpp" line="240"/>
        <source>No more events</source>
        <translation>Keine weiteren Ereignisse</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="271"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="272"/>
        <source>Clone</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="273"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../ImportDialog.ui" line="6"/>
        <source>Select calendar</source>
        <translation>Kalender wählen</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="44"/>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="50"/>
        <source>New calendar</source>
        <translation>Neuer Kalender</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="77"/>
        <source>Importing aborted</source>
        <translation>Import abgebrochen</translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="112"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n Ereignis</numerusform>
            <numerusform>%n Ereignisse</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="113"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n Aufgabe</numerusform>
            <numerusform>%n Aufgaben</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="114"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n Notiz</numerusform>
            <numerusform>%n Notizen</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="126"/>
        <location filename="../ImportDialog.cpp" line="194"/>
        <source>Error occurred</source>
        <translation>Ein Fehler ist aufgetreten</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="187"/>
        <source>Some items already in calendar</source>
        <translation>Es sind bereits Einträge im Kalender vorhanden</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="22"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="21"/>
        <source>Edit note</source>
        <translation>Notiz bearbeiten</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>New note</source>
        <translation>Neue Notiz</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="28"/>
        <source>New note</source>
        <translation>Neue Notiz</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="47"/>
        <source>Notes</source>
        <translation>Notizen</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="124"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="125"/>
        <source>Clone</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="126"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="63"/>
        <source>Month</source>
        <translation>Monat</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="64"/>
        <source>Week</source>
        <translation>Woche</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="65"/>
        <source>Agenda</source>
        <translation>Planung</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="66"/>
        <source>Tasks</source>
        <translation>Aufgaben</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="67"/>
        <source>Notes</source>
        <translation>Notizen</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="68"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="60"/>
        <source>Previous month</source>
        <translation>Vorheriger Monat</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="61"/>
        <source>Next month</source>
        <translation>Nächster Monat</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="62"/>
        <source>Jump to today</source>
        <translation>Gehe zu: Heute</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Jump to</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>New event</source>
        <translation>Neues Ereignis</translation>
    </message>
</context>
<context>
    <name>NewComponentWidget</name>
    <message>
        <location filename="../NewComponentWidget.h" line="24"/>
        <source>New event</source>
        <translation>Neues Ereignis</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../CWrapper.h" line="59"/>
        <source>Private</source>
        <translation>Privat</translation>
    </message>
    <message>
        <location filename="../CWrapper.h" line="61"/>
        <source>Birthdays</source>
        <translation>Geburtstage</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Wiederholung</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
        <source>Repeat</source>
        <translation>Wiederholung</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
        <source>View</source>
        <translation>Zeigen</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Daily</source>
        <translation>Täglich</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Weekly</source>
        <translation>Wöchentlich</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Monthly</source>
        <translation>Monatlich</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
        <source>Yearly</source>
        <translation>Jährlich</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
        <source>Interval</source>
        <translation>Intervall</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Forever</source>
        <translation>Für immer</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Until</source>
        <translation>Bis</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
        <source>Count</source>
        <translation>Anzahl</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
        <source>Week start</source>
        <translation>Wochenanfang</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="36"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="37"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="39"/>
        <source>External</source>
        <translation>Extern</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="41"/>
        <source>Every day</source>
        <translation>Jeden Tag</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="43"/>
        <source>Every workday</source>
        <translation>Jeden Arbeitstag</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="45"/>
        <source>Every week</source>
        <translation>Jede Woche</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="47"/>
        <source>Every month</source>
        <translation>Jeden Monat</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="49"/>
        <source>Every year</source>
        <translation>Jedes Jahr</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="51"/>
        <source>Complex</source>
        <translation>Komplex</translation>
    </message>
</context>
<context>
    <name>RulePickDialog</name>
    <message>
        <location filename="../recurrence/RulePickDialog.ui" line="6"/>
        <source>Select rule</source>
        <translation>Regel auswählen</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="16"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="17"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>RulePickSelector</name>
    <message>
        <location filename="../recurrence/RulePickSelector.cpp" line="14"/>
        <source>Rule %1 of %2</source>
        <translation>Regel %1 von %2</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="31"/>
        <source>Edit calendars</source>
        <translation>Kalender bearbeiten</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="41"/>
        <source>Alarm tone</source>
        <translation>Alarmton</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="51"/>
        <source>Delete events</source>
        <translation>Ereignisse löschen</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="61"/>
        <source>Delete tasks</source>
        <translation>Aufgaben löschen</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="71"/>
        <source>First day of week</source>
        <translation>Erster Tag der Woche</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="81"/>
        <source>Editable time zones</source>
        <translation>Editierbare Zeitzonen</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="88"/>
        <source>Date formats</source>
        <translation>Datumsformate</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="19"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="66"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="68"/>
        <location filename="../settings/SettingsDialog.cpp" line="70"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Älter als %n Woche</numerusform>
            <numerusform>Älter als %n Wochen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="72"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Älter als %n Monat</numerusform>
            <numerusform>Älter als %n Monate</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="74"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Älter als %n Jahr</numerusform>
            <numerusform>Älter als %n Jahre</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TimePickDialog</name>
    <message>
        <location filename="../TimePickDialog.cpp" line="11"/>
        <source>Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimePickDialog.cpp" line="13"/>
        <source>Select time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Time zone</source>
        <translation>Zeitzone</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="56"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="63"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="28"/>
        <source>Edit task</source>
        <translation>Aufgabe bearbeiten</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="31"/>
        <source>New task</source>
        <translation>Neue Aufgabe</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Aufgabe</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Fällig</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="169"/>
        <source>Edit task</source>
        <translation>Aufgabe bearbeiten</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="174"/>
        <source>Delete task</source>
        <translation>Aufgabe löschen</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="179"/>
        <source>Clone task</source>
        <translation>Aufgabe duplizieren</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="184"/>
        <source>Automatic links</source>
        <translation>Automatische Verknüpfungen</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="171"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="172"/>
        <source>Clone</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="173"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="34"/>
        <location filename="../TodosPlug.cpp" line="329"/>
        <source>New task</source>
        <translation>Neue Aufgabe</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Hide completed</source>
        <translation>Erledigte ausblenden</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="42"/>
        <source>Group by calendar</source>
        <translation>Nach Kalender gruppieren</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="43"/>
        <source>Delete completed</source>
        <translation>Erledigte löschen</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="71"/>
        <source>Tasks</source>
        <translation>Aufgaben</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="332"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="333"/>
        <source>Clone</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="334"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="379"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Erledigte Aufgaben aus allen Kalendern löschen?</translation>
    </message>
</context>
<context>
    <name>TunePickDialog</name>
    <message>
        <location filename="../settings/TunePickDialog.ui" line="6"/>
        <source>Choose alarm tone</source>
        <translation>Alarmton auswählen</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="17"/>
        <source>More</source>
        <translation>Mehr</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="67"/>
        <source>Add alarm tone</source>
        <translation>Alarmton hinzufügen</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="33"/>
        <source>w%1</source>
        <translation>KW%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Previous week</source>
        <translation>Vorherige Woche</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Next week</source>
        <translation>Nächste Woche</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to today</source>
        <translation>Gehe zu: Heute</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>Jump to</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="47"/>
        <source>New event</source>
        <translation>Neues Ereignis</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="70"/>
        <source>Week %1 (%2)</source>
        <translation>Woche %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="364"/>
        <source>All day</source>
        <translation>Ganzer
Tag</translation>
    </message>
</context>
<context>
    <name>ZonePickDialog</name>
    <message>
        <location filename="../ZonePickDialog.ui" line="6"/>
        <source>Time zone</source>
        <translation>Zeitzone</translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.ui" line="39"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.cpp" line="79"/>
        <source>Current</source>
        <translation>Aktuell</translation>
    </message>
</context>
</TS>
